# QMK CLI
[![CLI Setup](https://github.com/qmk/qmk_cli/workflows/CLI%20Setup/badge.svg)](https://github.com/qmk/qmk_cli/actions?query=workflow%3A%22CLI+Setup%22)  

A program to help users work with [QMK Firmware](https://qmk.fm/).

# Features

* Interact with your qmk_firmware tree from any location
* Use `qmk clone` to pull down anyone's `qmk_firmware` fork
* Setup your build environment with `qmk setup`
* Check that your environment is correctly setup with `qmk doctor`
* Integrates with qmk_firmware for additional functionality:
    * `qmk compile`
    * `qmk console`
    * `qmk flash`
    * `qmk lint`
    * ...and many more!

# Quickstart

* `python3 -m pip install qmk`
* `qmk setup`

Full documentation: <https://docs.qmk.fm/#/tutorial>
